@@ -177,7 +177,7 @@ function play(player, value) {
         var boardSize = levelsProperties[items.mode - 1].boardSize;
         if (moveCount <= (boardSize - 1)) {
             items.answerBallsPlacement.children[moveCount].visible = true;
-            if (player == 1) {
+            if (player === 1) {
                 items.answerBallsPlacement.children[moveCount].source = url + "ball_1.svg";
             } else {
                 items.answerBallsPlacement.children[moveCount].source = url + "ball_2.svg";
@@ -186,17 +186,17 @@ function play(player, value) {
         // one of the players has won
         if (moveCount == (boardSize - 1)) {
             items.okArea.enabled = false;
-            if (gameMode == 2) {
+            if (gameMode === 2) {
                 items.isPlayer1Beginning = !items.isPlayer1Beginning;
             }
-            if (player == 2) {
+            if (player === 2) {
                 items.player1score.win();
                 items.player2score.endTurn();
                 items.bonus.good("flower");
             } else {
                 items.player1score.endTurn();
                 items.player2score.win();
-                if (gameMode == 1) {
+                if (gameMode === 1) {
                     items.bonus.bad("flower");
                 }
                 else {
@@ -209,17 +209,17 @@ function play(player, value) {
 
     items.isPlayer1Turn = !items.isPlayer1Turn;
 
-    if (player == 1 && gameMode == 1) {
+    if (player === 1 && gameMode === 1) {
         items.player1score.endTurn();
         items.player2score.beginTurn();
         items.okArea.enabled = false;
         items.trigTuxMove.start();
-    } else if (player == 2 && gameMode == 1) {
+    } else if (player === 2 && gameMode === 1) {
         items.player2score.endTurn();
         items.player1score.beginTurn();
         items.okArea.enabled = true;
-    } else if (gameMode == 2) {
-        if (player == 1) {
+    } else if (gameMode === 2) {
+        if (player === 1) {
             items.player1score.endTurn();
             items.player2score.beginTurn();
         } else {
