@@ -44,6 +44,7 @@ function stop() {
 }
 
 function initLevel() {
+    items.levelComplete = false
     items.bar.level = currentLevel + 1
     items.containerModel.clear()
     currentQuestion = 0
@@ -52,52 +53,52 @@ function initLevel() {
         case 0:
             items.instructions = ""
             items.brailleCodeSeen = true
-            currentDataSet = dataset[0]
+            currentDataSet = dataset[0].slice()
             break
         case 1:
-            items.instructions = qsTr("Now it's a little bit harder without the braille map.")
+            items.instructions = qsTr("Now it's a little bit harder without the reference.")
             items.brailleCodeSeen = false
-            currentDataSet = dataset[0]
+            currentDataSet = dataset[0].slice()
             break
         case 2:
-            items.instructions = qsTr("Look at the Braille character map and observe how similar the first and second line are.")
+            items.instructions = qsTr("Look at the braille character chart and observe how similar the first and second lines are.")
             items.brailleCodeSeen = true
-            currentDataSet = dataset[1]
+            currentDataSet = dataset[1].slice()
             break
         case 3:
-            items.instructions = qsTr("Now it's a little bit harder without the braille map.")
+            items.instructions = qsTr("Now it's a little bit harder without the reference.")
             items.brailleCodeSeen = false
-            currentDataSet = dataset[1]
+            currentDataSet = dataset[1].slice()
             break
         case 4:
-            items.instructions = qsTr("Again, similar as the first line but take care, the 'W' letter was added afterwards.")
+            items.instructions = qsTr("Again, similar to the first line in the character chart but take care, the 'W' letter was added afterward.")
             items.brailleCodeSeen = true
-            currentDataSet = dataset[2]
+            currentDataSet = dataset[2].slice()
             break
         case 5:
-            items.instructions = qsTr("Now it's a little bit harder without the braille map.")
+            items.instructions = qsTr("Now it's a little bit harder without the reference.")
             items.brailleCodeSeen = false
-            currentDataSet = dataset[2]
+            currentDataSet = dataset[2].slice()
             break
         case 6:
             items.instructions = qsTr("This is easy, numbers are the same as letters from A to J.")
             items.brailleCodeSeen = true
-            currentDataSet = dataset[3]
+            currentDataSet = dataset[3].slice()
             break
         case 7:
-            items.instructions = qsTr("Now it's a little bit harder without the braille map.")
+            items.instructions = qsTr("Now it's a little bit harder without the reference.")
             items.brailleCodeSeen = false
-            currentDataSet = dataset[3]
+            currentDataSet = dataset[3].slice()
             break
         case 8:
             items.instructions = ""
             items.brailleCodeSeen = true
-            currentDataSet = dataset[4]
+            currentDataSet = dataset[4].slice()
             break
         case 9:
-            items.instructions = qsTr("Now it's a little bit harder without the braille map.")
+            items.instructions = qsTr("Now it's a little bit harder without the reference.")
             items.brailleCodeSeen = false
-            currentDataSet = dataset[4]
+            currentDataSet = dataset[4].slice()
             break
     }
 
@@ -131,20 +132,21 @@ function previousLevel() {
     initLevel();
 }
 
-function nextQuestion() {
+function goodAnswer() {
+    items.score.currentSubLevel ++
+    items.score.playWinAnimation()
     if(currentDataSet.length <= ++currentQuestion) {
+        items.levelComplete = true
         items.bonus.good("flower")
-    } else {
-        // Let's not change the question immediately to let the
-        // children see his answer.
-        // We just set the opacity to 0, the questionItem will then grab
-        // the new question by itself
-        items.questionItem.opacity = 0.1
-        items.questionItem.opacity = 0
-        items.score.currentSubLevel ++
     }
 }
 
+function nextQuestion() {
+    // We just set the opacity to 0, the questionItem will then grab
+    // the new question by itself
+    items.questionItem.opacity = 0
+}
+
 function getCurrentTextQuestion() {
     return currentDataSet[currentQuestion].text.arg(getCurrentLetter())
 }
