@@ -57,7 +57,7 @@ function initLevel() {
 }
 
 function nextLevel() {
-    if(numberOfLevel <= ++currentLevel ) {
+    if(numberOfLevel <= ++currentLevel) {
         currentLevel = 0
     }
     initLevel();
@@ -295,7 +295,7 @@ function randomMove() {
         return
     }
     // Get all possible moves
-    var moves = Engine.p4_parse(state, state.to_play, 0, 0)
+    var moves = Engine.p4_parse(state, state.to_play, state.enpassant, 0)
     moves = Core.shuffle(moves)
     var move = state.move(moves[0][1], moves[0][2])
     if(move.ok) {
@@ -315,11 +315,19 @@ function clearAcceptMove() {
 
 // Highlight the possible moves for the piece at position 'from'
 function showPossibleMoves(from) {
-    var result = Engine.p4_parse(state, state.to_play, 0, 0)
+    var result = Engine.p4_parse(state, state.to_play, state.enpassant, 0)
     clearAcceptMove()
     var fromEngine = viewPosToEngine(from)
     for(var i=0; i < result.length; ++i) {
         if(fromEngine === result[i][1]) {
+            // we don't want to display invalid moves
+            var move = Engine.p4_make_move(state, result[i][1], result[i][2]);
+            //is it check?
+            if (Engine.p4_check_check(state, state.to_play)) {
+                Engine.p4_unmake_move(state, move);
+                continue;
+            }
+            Engine.p4_unmake_move(state, move);
             var pos = engineToViewPos(result[i][2])
             items.squares.getSquareAt(pos)['acceptMove'] = true
         }
