@@ -44,7 +44,7 @@ var mode;
 
 function start(_items, _mode)
 {
-    Core.checkForVoices(_items.main);
+    Core.checkForVoices(_items.activityPage);
 
     items = _items;
     mode = _mode;
@@ -101,7 +101,7 @@ function loadLevels()
             levels[i].answers = levels[i].answers.toLocaleLowerCase();
         } else {
             levels[i].questions = levels[i].questions.toLocaleUpperCase();
-            levels[i].answers = levels[i].answers.toLocaleUpperCase();        
+            levels[i].answers = levels[i].answers.toLocaleUpperCase();
         }
     }
 }
@@ -191,10 +191,14 @@ function previousLevel() {
 function nextSubLevel() {
     items.audioVoices.clearQueue()
     if(++currentSubLevel >= maxSubLevel) {
-        currentSubLevel = 0
-        nextLevel()
+        if(items.audioVoices.playbackState == 1) {
+            items.goToNextLevel = true
+        } else {
+            items.bonus.good("flower")
+        }
+    } else {
+        initLevel();
     }
-    initLevel();
 }
 
 function checkAnswer(index)
@@ -202,9 +206,18 @@ function checkAnswer(index)
     var modelEntry = items.trainModel.get(index);
     if (modelEntry.letter === currentLetter) {
         playLetter(modelEntry.letter);
-        items.bonus.good("flower");
+        if(items.audioVoices.playbackState == 1) {
+            items.goToNextSubLevel = true
+        } else {
+            nextSubLevel();
+        }
         return true
     } else {
         return false
     }
 }
+
+function focusEventHandler() {
+    if (items && items.eventHandler)
+        items.eventHandler.forceActiveFocus();
+}
