@@ -23,8 +23,8 @@ function get() {
     {
         "imageName1": "paper.svg",
         "imageName2": "A1.svg",
-        "coordinates": [[136,402],[154,359],[171,316],[189,276],[207,230],[225,187],[242,144],[260,101],[278,58],[296,101],[314,144],[332,187],[350,230],[368,276],[386,316],[403,359],[420,402],[187,286],[235,286],[282,286],[330,286],[378,286]],
-        "coordinates2": [1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,2,2,2,2,2],
+        "coordinates": [[278,58],[260,100],[242,144],[225,187],[207,230],[189,276],[171,316],[154,359],[136,402],[278,58],[296,104],[314,144],[332,187],[350,230],[368,276],[386,316],[403,359],[420,402],[187,286],[235,286],[282,286],[330,286],[378,286]],
+        "coordinates2": [1,1,1,1,1,1,1,1,1,2,2,2,2,2,2,2,2,2,3,3,3,3,3],
         "sound": GCompris.ApplicationInfo.getAudioFilePath("voices-$CA/$LOCALE/alphabet/"+ Core.getSoundFilenamForChar("a"))
     },
     {
@@ -64,7 +64,8 @@ function get() {
     {
         "imageName1": "paper.svg",
         "imageName2": "G1.svg",
-        "coordinates": [[446,147],[434,124],[411,97],[383,82],[347,70],[317,66],[275,73],[242,86],[208,107],[183,136],[164,172],[161,206],[165,256],[179,297],[206,328],[238,350],[282,366],[320,369],[362,366],[397,355],[428,344],[456,315],[455,288],[455,262],[455,234],[423,235],[395,235],[369,235],[339,235]],
+        "coordinates": [[446,147],[434,124],[411,97],[383,82],[347,70],[317,66],[275,73],[242,86],[208,107],[183,136],[164,172],[161,206],[165,256],[179,297],[206,328],[238,350],[282,366],[320,369],[362,366],[397,355],[428,344],[456,315],[455,288],[455,262],[455,234],[339,235],[369,235],[395,235],[423,235]],
+        "coordinates2": [1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,2,2,2,2],
         "sound": GCompris.ApplicationInfo.getAudioFilePath("voices-$CA/$LOCALE/alphabet/"+ Core.getSoundFilenamForChar("g"))
     },
     {
@@ -102,19 +103,21 @@ function get() {
     {
         "imageName1": "paper.svg",
         "imageName2": "M1.svg",
-        "coordinates": [[144,413],[144,377],[144,337],[144,297],[144,263],[144,227],[144,194],[144,148],[144,106],[144,73],[186,103],[198,137],[211,175],[222,204],[234,234],[249,263],[259,291],[274,325],[286,360],[302,393],[311,413],[325,379],[339,344],[354,311],[364,280],[376,246],[387,217],[401,184],[413,150],[426,115],[446,82],[462,114],[462,142],[462,171],[462,201],[462,233],[462,266],[462,306],[462,340],[462,372],[462,405]],
+        "coordinates": [[144,73],[144,106],[144,148],[144,194],[144,227],[144,263],[144,297],[144,337],[144,377],[144,413],[147,75],[174,80],[186,103],[198,137],[211,175],[222,204],[234,234],[249,263],[259,291],[274,325],[286,360],[302,393],[311,413],[325,379],[339,344],[354,311],[364,280],[376,246],[387,217],[401,184],[413,150],[426,115],[446,82],[462,114],[462,142],[462,171],[462,201],[462,233],[462,266],[462,306],[462,340],[462,372],[462,405]],
+        "coordinates2": [1,1,1,1,1,1,1,1,1,1],
         "sound": GCompris.ApplicationInfo.getAudioFilePath("voices-$CA/$LOCALE/alphabet/"+ Core.getSoundFilenamForChar("m"))
     },
     {
         "imageName1": "paper.svg",
         "imageName2": "N1.svg",
-        "coordinates": [[186,376],[186,349],[186,324],[186,302],[186,279],[186,255],[186,226],[186,195],[186,172],[186,146],[186,127],[186,96],[206,118],[219,130],[234,150],[250,168],[265,185],[280,201],[295,223],[313,243],[327,260],[345,287],[368,312],[390,334],[410,349],[431,368],[431,343],[431,328],[431,296],[431,267],[431,245],[431,220],[431,194],[431,163],[431,137],[431,111],[431,96]],
+        "coordinates": [[186,96],[186,127],[186,146],[186,172],[186,195],[186,226],[186,255],[186,279],[186,302],[186,324],[186,349],[186,374],[186,96],[206,118],[219,130],[234,150],[250,168],[265,185],[280,201],[295,223],[313,243],[327,260],[345,287],[368,312],[390,334],[410,349],[431,368],[431,343],[431,328],[431,296],[431,267],[431,245],[431,220],[431,194],[431,163],[431,137],[431,111],[431,96]],
+        "coordinates2": [1,1,1,1,1,1,1,1,1,1,1,1,1],
         "sound": GCompris.ApplicationInfo.getAudioFilePath("voices-$CA/$LOCALE/alphabet/"+ Core.getSoundFilenamForChar("n"))
     },
     {
         "imageName1": "paper.svg",
         "imageName2": "O1.svg",
-        "coordinates":  [[291,71],[326,77],[360,89],[393,108],[417,132],[440,168],[452,209],[457,251],[453,302],[441,335],[426,369],[394,394],[357,415],[322,430],[284,430],[246,424],[215,411],[184,394],[160,364],[140,331],[125,292],[118,246],[131,195],[144,155],[165,122],[193,96],[228,78],[270,66]],
+        "coordinates": [[291,71],[270,66],[228,78],[193,96],[165,122],[144,155],[131,195],[118,246],[125,292],[140,331],[160,364],[184,394],[215,411],[246,424],[284,430],[322,430],[357,415],[394,394],[426,369],[441,335],[453,302],[457,251],[452,209],[440,168],[417,132],[393,108],[360,89],[326,77]],
         "sound": GCompris.ApplicationInfo.getAudioFilePath("voices-$CA/$LOCALE/alphabet/"+ Core.getSoundFilenamForChar("o"))
     },
     {
@@ -127,7 +130,7 @@ function get() {
     {
         "imageName1": "paper.svg",
         "imageName2": "Q1.svg",
-        "coordinates": [[321,107],[358,108],[393,122],[430,153],[456,193],[464,233],[466,270],[455,308],[423,347],[390,368],[346,382],[297,382],[260,376],[222,360],[193,332],[175,303],[161,270],[160,226],[172,188],[195,148],[233,120],[271,107],[299,99],[329,324],[360,337],[390,350],[413,366],[444,383],[473,397],[492,406]],
+        "coordinates": [[321,107],[299,99],[271,107],[233,120],[195,148],[172,188],[160,226],[161,270],[175,303],[193,332],[222,360],[260,376],[292,382],[346,382],[390,368],[423,347],[455,308],[466,270],[464,233],[456,193],[430,153],[393,122],[358,108],[329,324],[360,337],[390,350],[413,366],[444,383],[473,397],[492,406]],
         "coordinates2": [1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,2,2,2,2,2,2,2],
         "sound": GCompris.ApplicationInfo.getAudioFilePath("voices-$CA/$LOCALE/alphabet/"+ Core.getSoundFilenamForChar("q"))
     },
@@ -179,8 +182,8 @@ function get() {
     {
         "imageName1": "paper.svg",
         "imageName2": "Y1.svg",
-        "coordinates": [[165,91],[180,122],[200,154],[219,183],[235,213],[260,253],[285,292],[308,267],[331,234],[343,211],[360,186],[375,158],[388,136],[411,99],[289,303],[289,339],[289,371],[289,395],[289,420],[289,446]],
-        "coordinates2": [1,1,1,1,1,1,1,1,1,1,1,1,1,1,2,2,2,2,2,2],
+        "coordinates": [[165,91],[180,122],[200,154],[219,183],[235,213],[260,253],[285,292],[411,99],[388,136],[375,158],[360,186],[343,211],[331,234],[308,267],[289,303],[289,339],[289,371],[289,395],[289,420],[289,446]],
+        "coordinates2": [1,1,1,1,1,1,1,2,2,2,2,2,2,2,3,3,3,3,3,3],
         "sound": GCompris.ApplicationInfo.getAudioFilePath("voices-$CA/$LOCALE/alphabet/"+ Core.getSoundFilenamForChar("y"))
     },
     {
