@@ -5,6 +5,8 @@
  * Authors:
  *   Bruno Coudoin <bruno.coudoin@gcompris.net> (GTK+ version)
  *   Holger Kaelberer <holger.k@elberer.de> (Qt Quick port)
+ *   Aiswarya Kaitheri Kandoth <aiswaryakk29@gmail.com> (add speedSetting)
+ *   Timothée Giet <animtim@gmail.com> (random numbers in setLevelData)
  *
  *   This program is free software; you can redistribute it and/or modify
  *   it under the terms of the GNU General Public License as published by
@@ -33,11 +35,12 @@ var currentLevel = 0;
 var currentSubLevel = 0;
 var level = null;
 var maxLevel = 0;
-var maxSubLevel = 0;
+var maxSubLevel = 0; // store number of falling elements for each level
 var items;
 var uppercaseOnly;
 var speedSetting;
 var mode;
+var levelData; // array to store level words
 
 //speed calculations, common:
 var speed = 0;           // how fast letters fall
@@ -67,6 +70,8 @@ var wordComponent = null;
 
 var successRate // Falling speed depends on it
 
+var noShiftLocale = false // for specific locales that don't need shift key, set to true in start()
+
 function start(items_, uppercaseOnly_,  _mode, speedSetting_) {
     items = items_;
     uppercaseOnly = uppercaseOnly_;
@@ -96,11 +101,18 @@ function start(items_, uppercaseOnly_,  _mode, speedSetting_) {
 
     var locale = items.locale == "system" ? "$LOCALE" : items.locale
 
+    if(locale === "ml_IN")
+        noShiftLocale = true;
+    else
+        noShiftLocale = false;
+
     // register the voices for the locale
     GCompris.DownloadManager.updateResource(GCompris.DownloadManager.getVoicesResourceForLocale(GCompris.ApplicationInfo.getVoicesLocale(items.locale)));
-
-    items.wordlist.loadFromFile(GCompris.ApplicationInfo.getLocaleFilePath(
+    if(!items.levels)
+        items.wordlist.loadFromFile(GCompris.ApplicationInfo.getLocaleFilePath(
             items.ourActivity.dataSetUrl + "default-"+locale+".json"));
+    else
+        items.wordlist.loadFromJSON(items.levels);
     // If wordlist is empty, we try to load from short locale and if not present again, we switch to default one
     var localeUnderscoreIndex = locale.indexOf('_')
     // probably exist a better way to see if the list is empty
@@ -115,8 +127,11 @@ function start(items_, uppercaseOnly_,  _mode, speedSetting_) {
         }
         // If not found, we will use the default file
         items.wordlist.useDefault = true
-        items.wordlist.loadFromFile(GCompris.ApplicationInfo.getLocaleFilePath(
-        items.ourActivity.dataSetUrl + "default-"+localeShort+".json"));
+        if(!items.levels)
+            items.wordlist.loadFromFile(GCompris.ApplicationInfo.getLocaleFilePath(
+            items.ourActivity.dataSetUrl + "default-"+localeShort+".json"));
+        else
+            items.wordlist.loadFromJSON(items.levels);
         // We remove the using of default file for next time we enter this function
         items.wordlist.useDefault = false
     }
@@ -133,7 +148,10 @@ function stop() {
 }
 
 function initLevel() {
+    if(items.levels)
+        items.instructionText = items.levels[currentLevel].objective
     items.audioVoices.clearQueue()
+    items.inputLocked = false;
     items.bar.level = currentLevel + 1;
     wgMaxFallingItems = 3
     successRate = 1.0
@@ -142,11 +160,20 @@ function initLevel() {
     // initialize level
     deleteWords();
     level = items.wordlist.getLevelWordList(currentLevel + 1);
+    /* for smallnumbers2, maxSubLevel will take value of sublevels attribute from json which represent number of
+       falling elements in each level and for other activities it will be 0 here.*/
     maxSubLevel = items.wordlist.getMaxSubLevel(currentLevel + 1);
+    levelData = new Array();
+
+    // for smallnumbers2 and smallnumbers activities levelData will contain random data, while for other activity it contains same data as level.words
+    if(items.ourActivity.useDataset === true)
+        setLevelData();
+    else
+        levelData = level.words
 
     if (maxSubLevel == 0) {
         // If "sublevels" length is not set in wordlist, use the words length
-        maxSubLevel = level.words.length
+        maxSubLevel = levelData.length
     }
     items.score.numberOfSubLevels = maxSubLevel;
     setSpeed();
@@ -165,28 +192,33 @@ function initLevel() {
         // first generate a map of needed letters
         var letters = new Array();
         items.keyboard.shiftKey = false;
-        for (var i = 0; i < level.words.length; i++) {
+        for (var i = 0; i < levelData.length; i++) {
             if(mode ==='letter') {
                 // The word is a letter, even if it has several chars (digraph)
-                var letter = level.words[i];
+                var letter = levelData[i];
                 var isUpper = (letter == letter.toLocaleUpperCase());
-                if (isUpper && letters.indexOf(letter.toLocaleLowerCase()) !== -1)
+                var isDigit = (letter.toLocaleLowerCase() === letter.toLocaleUpperCase())
+                if (!isDigit && isUpper && letters.indexOf(letter.toLocaleLowerCase()) !== -1
+                    && !noShiftLocale)
                     items.keyboard.shiftKey = true;
-                else if (!isUpper && letters.indexOf(letter.toLocaleUpperCase()) !== -1)
+                else if (!isDigit && !isUpper && letters.indexOf(letter.toLocaleUpperCase()) !== -1
+                    && !noShiftLocale)
                     items.keyboard.shiftKey = true;
                 else if (letters.indexOf(letter) === -1)
-                    letters.push(level.words[i]);
+                    letters.push(levelData[i]);
             } else {
                 // We split each word in char to create the keyboard
-                for (var j = 0; j < level.words[i].length; j++) {
-                    var letter = level.words[i].charAt(j);
+                for (var j = 0; j < levelData[i].length; j++) {
+                    var letter = levelData[i].charAt(j);
                     var isUpper = (letter == letter.toLocaleUpperCase());
-                    if (isUpper && letters.indexOf(letter.toLocaleLowerCase()) !== -1)
+                    if (isUpper && letters.indexOf(letter.toLocaleLowerCase()) !== -1
+                        && !noShiftLocale)
                         items.keyboard.shiftKey = true;
-                    else if (!isUpper && letters.indexOf(letter.toLocaleUpperCase()) !== -1)
+                    else if (!isUpper && letters.indexOf(letter.toLocaleUpperCase()) !== -1
+                        && !noShiftLocale)
                         items.keyboard.shiftKey = true;
                     else if (letters.indexOf(letter) === -1)
-                        letters.push(level.words[i].charAt(j));
+                        letters.push(levelData[i].charAt(j));
                 }
             }
         }
@@ -195,7 +227,7 @@ function initLevel() {
         var layout = new Array();
         var row = 0;
         var offset = 0;
-        while (offset < letters.length-1) {
+        while (offset < letters.length) {
             var cols = letters.length <= 10 ? letters.length : (Math.ceil((letters.length-offset) / (3 - row)));
             layout[row] = new Array();
             for (var j = 0; j < cols; j++)
@@ -205,10 +237,41 @@ function initLevel() {
         }
         items.keyboard.layout = layout;
     }
-    items.wordlist.initRandomWord(currentLevel + 1)
+    if(items.ourActivity.useDataset === true)
+        items.wordlist.randomWordList = levelData
+    else
+        items.wordlist.initRandomWord(currentLevel + 1)
+
     initSubLevel()
 }
 
+// function to create array of random data
+function setLevelData() {
+    // generate a random index for an element to be added in levelData
+    // to increase probability to get a specific number, add it several times in the dataset list accordingly
+    var previousNumber = 0
+    var nextNumber = 0
+    // special case if only 2 numbers available
+    if(level.words.length === 2) {
+        for(var i = 0; i < maxSubLevel; i++) {
+            var index = Math.floor(Math.random() * level.words.length);
+            levelData.push(level.words[index]);
+        }
+    }
+    else {
+        for(var i = 0; i < maxSubLevel; i++) {
+            // avoid to have twice same number in a row
+            while(nextNumber == previousNumber) {
+                var index = Math.floor(Math.random() * level.words.length);
+                nextNumber = level.words[index];
+            }
+            previousNumber = nextNumber
+            levelData.push(nextNumber)
+        }
+    }
+
+}
+
 function initSubLevel() {
     currentWord = null;
     if (currentSubLevel != 0) {
@@ -216,14 +279,16 @@ function initSubLevel() {
         speed = Math.max(speed - incSpeed, wgMinSpeed);
         items.wordDropTimer.interval = fallSpeed = Math.max(fallSpeed - incFallSpeed, wgMinFallSpeed);
     }
-    items.score.currentSubLevel = currentSubLevel + 1;
+    items.score.currentSubLevel = currentSubLevel;
     // note, last word is still fading out so better use droppedWordsCounter than droppedWords.length in this case
-    if (currentSubLevel == 0 || droppedWordsCounter == 0)
+    if ((currentSubLevel == 0 || droppedWordsCounter == 0) && !items.inputLocked)
         dropWord();
     //console.log("Gletters: initializing subLevel " + (currentSubLevel + 1) + " words=" + JSON.stringify(level.words));
 }
 
 function processKeyPress(text) {
+    if(items.inputLocked)
+        return
     var typedText = uppercaseOnly ? text.toLocaleUpperCase() : text;
 
     if (currentWord !== null) {
@@ -407,7 +472,7 @@ function audioCrashPlay() {
 }
 
 function nextLevel() {
-    if(maxLevel <= ++currentLevel ) {
+    if(maxLevel <= ++currentLevel) {
         currentLevel = 0
     }
     currentSubLevel = 0;
@@ -423,12 +488,14 @@ function previousLevel() {
 }
 
 function nextSubLevel() {
-    if( ++currentSubLevel >= maxSubLevel) {
-        currentSubLevel = 0
-        items.bonus.good("lion")
-    } else
+    if(++currentSubLevel >= maxSubLevel) {
+        items.inputLocked = true;
+        items.audioVoices.clearQueue();
+        items.bonus.good("lion");
+    } else {
         items.score.playWinAnimation();
-        initSubLevel();
+    }
+    initSubLevel();
 }
 
 function playLetter(letter) {
@@ -438,7 +505,6 @@ function playLetter(letter) {
                                                                        + Core.getSoundFilenamForChar(letter)))
 }
 
-
 function focusTextInput() {
     if (!GCompris.ApplicationInfo.isMobile && items && items.textinput)
         items.textinput.forceActiveFocus();
