@@ -23,31 +23,41 @@
 .import QtQuick 2.6 as Quick
 
 var _currentLevel = 0
-var _numberOfLevel = 14
+var _numberOfLevel
 var _main
 var _bar
 var _bonus
 var _type
 var _operator
 var _modelCells
+var _levels
+var _useMultipleDataset
 
-function start(modelCells, bar, bonus, type, operator) {
-    _bar = bar
-    _bonus = bonus
+function start(items, type, useMultipleDataset) {
+    _levels = items.levels
+    _useMultipleDataset = useMultipleDataset
+    _bar = items.bar
+    _bonus = items.bonus
     _currentLevel = 0
     _type = type
-    _operator = operator
-    _modelCells = modelCells
-    if (type != "equality" && type != "inequality") {
-        _numberOfLevel = 8
-    }
+    _operator = items.operator
+    _modelCells = items.modelCells
+    _numberOfLevel = (_useMultipleDataset) ? _levels.length : 8
 }
 
 function stop() {
 }
 
+function initLevel() {
+    if(_type === "equality" || _type === "inequality") {
+        _operator = _levels[_currentLevel].operator
+    }
+    fillAllGrid();
+    _bar.level = _currentLevel + 1;
+}
+
 function nextLevel() {
-    if(_numberOfLevel <= ++_currentLevel ) {
+    if(_numberOfLevel <= ++_currentLevel) {
         _currentLevel = 0
     }
 }
@@ -59,20 +69,20 @@ function previousLevel() {
 }
 
 function getGoal() {
-    var goal
-    if (_type == "equality" || _type == "inequality") {
-        goal = _currentLevel + 6
-        if (_currentLevel > 6) {
-            goal = _currentLevel - 1
+    var goal = 0
+    if (_useMultipleDataset) {
+        goal = _levels[_currentLevel].goal
+    }
+    else {
+        if (_type == "multiples") {
+            goal = _currentLevel + 2
+        } else if (_type == "factors") {
+            var goalsFactor = [4, 6, 8, 10, 12, 15, 18, 20]
+            goal = goalsFactor[_currentLevel]
+        } else if (_type == "primes") {
+            var primenumbers = [2, 3, 5, 7, 11, 13, 17, 19, 23]
+            goal = primenumbers[_currentLevel + 1] + 1
         }
-    } else if (_type == "multiples") {
-        goal = _currentLevel + 2
-    } else if (_type == "factors") {
-        var goalsFactor = [4, 6, 8, 10, 12, 15, 18, 20]
-        goal = goalsFactor[_currentLevel]
-    } else if (_type == "primes") {
-        var primenumbers = [2, 3, 5, 7, 11, 13, 17, 19, 23]
-        goal = primenumbers[_currentLevel + 1] + 1
     }
 
     return goal
@@ -154,6 +164,31 @@ function genTime() {
     return time
 }
 
+function splitDivisionNumber(term) {
+    var term1 = term * Math.floor(Math.random() * 6 + 1)
+    var term2 = term1 / term
+
+    return [term1, term2]
+}
+
+function splitMultiplicationNumber(term) {
+    var factors = []
+    for (var div = 1; div < term + 1; ++div) {
+        if (getGoal() % div == 0) {
+            factors.push(div)
+        }
+    }
+    var term1 = factors[Math.floor(Math.random() * factors.length)]
+    var term2 = Math.floor(term / term1);
+
+    if (Math.random() < 0.5) {
+        return [term1, term2]
+    } else {
+        return [term2, term1]
+    }
+}
+
+
 function splitPlusNumber(term) {
     // Check if the term is odd
     var odd = term % 2
@@ -211,19 +246,25 @@ function fillAllGrid() {
     if (_type == "equality" || _type == "inequality") {
         for (var it = 0; it < 36; it++) {
             var terms
-            if (_operator == " + ") {
+            if (_operator === " + ") {
                 terms = splitPlusNumber(
                             genNumber())
-            } else {
+            } else if (_operator === " - ") {
                 terms = splitMinusNumber(
                             genNumber())
+            } else if(_operator === " * ") {
+                terms = splitMultiplicationNumber(
+                            genNumber())
+            } else if(_operator === " / ") {
+                terms = splitDivisionNumber(
+                            genNumber())
             }
 
             _modelCells.append({
-                                  number1: terms[0],
-                                  number2: terms[1],
-                                  show: true
-                              })
+                                   number1: terms[0],
+                                   number2: terms[1],
+                                   show: true
+                               })
         }
     } else if (_type == "primes") {
         for (var it = 0; it < 36; it++) {
@@ -240,46 +281,50 @@ function fillAllGrid() {
     }
 }
 
+function isExpressionEqualsToGoal(position){
+    if (_operator === " + ") {
+        if ((_modelCells.get(position).number1 + _modelCells.get(
+                 position).number2) == (getGoal())) {
+            return true
+        } else {
+            return false
+        }
+    } else if (_operator === " - ") {
+        if ((_modelCells.get(position).number1 - _modelCells.get(
+                 position).number2) == (getGoal())) {
+            return true
+        } else {
+            return false
+        }
+    } else if (_operator === " * ") {
+        if ((_modelCells.get(position).number1 * _modelCells.get(
+                 position).number2) === (getGoal())) {
+            return true
+        } else {
+            return false
+        }
+    } else if (_operator === " / ") {
+        if ((_modelCells.get(position).number1 / _modelCells.get(
+                 position).number2) === (getGoal())) {
+            return true
+        } else {
+            return false
+        }
+    }
+}
+
 function isAnswerCorrect(position) {
-    if (_type == "equality") {
-        if (_operator == " + ") {
-            if ((_modelCells.get(position).number1 + _modelCells.get(
-                     position).number2) == (getGoal())) {
-                return true
-            } else {
-                return false
-            }
-        } else {
-            if ((_modelCells.get(position).number1 - _modelCells.get(
-                     position).number2) == (getGoal())) {
-                return true
-            } else {
-                return false
-            }
-        }
-    } else if (_type == "inequality") {
-        if (_operator == " + ") {
-            if ((_modelCells.get(position).number1 + _modelCells.get(
-                     position).number2) != (getGoal())) {
-                return true
-            } else {
-                return false
-            }
-        } else {
-            if ((_modelCells.get(position).number1 - _modelCells.get(
-                     position).number2) != (getGoal())) {
-                return true
-            } else {
-                return false
-            }
-        }
-    } else if (_type == "multiples") {
+    if (_type === "equality") {
+        return isExpressionEqualsToGoal(position)
+    } else if (_type === "inequality") {
+        return (!isExpressionEqualsToGoal(position))
+    } else if (_type === "multiples") {
         if ((_modelCells.get(position).number1 / getGoal()) % 1 == 0) {
             return true
         } else {
             return false
         }
-    } else if (_type == "factors") {
+    } else if (_type === "factors") {
         if ((getGoal() / _modelCells.get(position).number1) % 1 == 0) {
             return true
         } else {
