@@ -45,6 +45,7 @@ function start() {
     lessonModelIndex = 0;
     currentSubLevel = 0;
     items.imageReview.stop()
+    items.menuScreen.stop()
 
     var locale = GCompris.ApplicationInfo.getVoicesLocale(items.locale)
 
@@ -61,10 +62,12 @@ function start() {
 
     items.menuModel.clear()
     items.menuModel.append(lessons)
-    savedPropertiesToLessons(items.dialogActivityConfig.dataToSave)
+    savedPropertiesToLessons(items.dialogActivityConfig.activityData)
     sortByFavorites();
 
-    items.menuScreen.start()
+    if(!items.background.englishFallback) {
+        items.menuScreen.start();
+    }
 }
 
 // Insert our specific properties in the lessons
@@ -166,6 +169,8 @@ function markProgress() {
 
 function playWord(word) {
     var locale = GCompris.ApplicationInfo.getVoicesLocale(items.locale)
+    items.audioVoices.stop()
+    items.audioVoices.clearQueue()
     return items.audioVoices.append(
                 GCompris.ApplicationInfo.getAudioFilePathForLocale(word, locale))
 }
@@ -173,3 +178,13 @@ function playWord(word) {
 function clearVoiceQueue() {
     items.audioVoices.clearQueue()
 }
+
+function focusEventInput() {
+    if(items && items.menuScreen && items.menuScreen.opacity === 1) {
+        items.menuScreen.forceActiveFocus();
+    } else if(items && items.imageReview && items.imageReview.opacity === 1 && items.imageReview.currentMiniGame === -1) {
+        items.imageReview.forceActiveFocus();
+    } else if(items && items.imageReview && items.imageReview.opacity === 1 && items.imageReview.currentMiniGame >= 0) {
+        items.imageReview.restoreMinigameFocus();
+    }
+}
