@@ -46,7 +46,7 @@ var clouds = new Array;
 var cloudsErased = new Array;
 
 function start(items_, dataset_) {
-    Core.checkForVoices(items_.background);
+    Core.checkForVoices(items_.activityPage);
 
     items = items_
     dataset = dataset_
@@ -300,7 +300,11 @@ function handleCollisionsWithCloud() {
 
                     if(currentSubLevel === numberOfSubLevels) {
                         /* Try the next level */
-                        items.bonus.good("flower")
+                        if(items.audioVoices.hasAudio) {
+                            items.goToNextLevel = true
+                        } else {
+                            items.bonus.good("flower")
+                        }
                     } else {
                         items.score.message = dataset[currentLevel].data[currentSubLevel]
                     }
