@@ -32,77 +32,39 @@ var iceBlocksLayout = [[0, 0],[1, 0],[2, 0],[3, 0],[4, 0],
 var tuxIceBlockNumber = 0
 var tuxIceBlockNumberGoal = 0
 var tuxIsMoving = false;
-var debuginttmp = 0
 var placeFishToReachBool = false
 
 var level = null;
 
-var levels = [
-            {
-                "maxNumber": 1, /* Max number on each domino side */
-                "minNumber": 1,
-                "numberOfFish": 3
-            },
-            {
-                "maxNumber": 2,
-                "minNumber": 1,
-                "numberOfFish": 4
-            },
-            {
-                "maxNumber": 3,
-                "minNumber": 1,
-                "numberOfFish": 5
-            },
-            {
-                "maxNumber": 4,
-                "minNumber": 1,
-                "numberOfFish": 5
-            },
-            {
-                "maxNumber": 5,
-                "minNumber": 2,
-                "numberOfFish": 5
-            },
-            {
-                "maxNumber": 6,
-                "minNumber": 3,
-                "numberOfFish": 5
-            },
-            {
-                "maxNumber": 7,
-                "minNumber": 4,
-                "numberOfFish": 5
-            },
-            {
-                "maxNumber": 8,
-                "minNumber": 4,
-                "numberOfFish": 5
-            },
-            {
-                "maxNumber": 9,
-                "minNumber": 5,
-                "numberOfFish": 5
-            },
-
+var fishes = [
+            "Benzfish.svg",
+            "blue-fish.svg",
+            "drunken_duck_cartoon_globefish_kugelfisch.svg",
+            "Fish02.svg",
+            "molumen_Codfish.svg",
+            "mystica_Aquarium_fish_-_Amphiprion_percula.svg",
+            "pepinux_Pez_dorado.svg",
+            "The_Whale-Fish.svg",
+            "Benzfish.svg",
+            "blue-fish.svg",
+            "drunken_duck_cartoon_globefish_kugelfisch.svg",
+            "Fish02.svg"
         ]
 
 var numberOfFish
 var fishIndex = -1
 
 var currentLevel = 0
-var numberOfLevel = levels.length
+var numberOfLevel = 0
 var items
 
-var url = "qrc:/gcompris/src/activities/reversecount/resource/"
-
-
 function start(items_) {
     items = items_
     currentLevel = 0
+    numberOfLevel = items.levels.length
     initLevel()
 }
 
-
 function stop() {
     fishIndex = -1
 }
@@ -112,8 +74,8 @@ function initLevel() {
 
     items.chooseDiceBar.value1 = 0
     items.chooseDiceBar.value2 = 0
-    items.chooseDiceBar.valueMax = levels[currentLevel].maxNumber
-    numberOfFish = levels[currentLevel].numberOfFish
+    items.chooseDiceBar.valueMax = items.levels[currentLevel].maxNumber
+    numberOfFish = items.levels[currentLevel].numberOfFish
 
     fishIndex = 0
     tuxIceBlockNumber = 0
@@ -125,7 +87,6 @@ function initLevel() {
     items.clockPosition = 4
 }
 
-
 function moveTux() {
     calculateTuxIceBlockNextPos()
 
@@ -142,13 +103,12 @@ function moveTux() {
     }
 }
 
-
 function moveTuxToNextIceBlock() {
-    tuxIsMoving = false;
+    tuxIsMoving = false
     tuxIceBlockNumber++
     tuxIceBlockNumber = tuxIceBlockNumber % iceBlocksLayout.length
 
-    if (tuxIceBlockNumber >= 0 && tuxIceBlockNumber <= 4)
+    if (tuxIceBlockNumber > 0 && tuxIceBlockNumber <= 4)
         items.tux.rotation = -90
     else if (tuxIceBlockNumber >= 5 && tuxIceBlockNumber <= 8)
         items.tux.rotation = 0
@@ -178,7 +138,7 @@ function moveTuxToNextIceBlock() {
         return
     }
 
-    items.audioEffects.play(url + 'icy_walk.wav')
+    items.audioEffects.play(items.resourceUrl + 'icy_walk.wav')
     //if tux reaches its position + dice number before reaching the fish, calculation was wrong
     if (tuxIceBlockNumber == tuxIceBlockNumberGoal) {
         items.clockPosition--
@@ -192,7 +152,6 @@ function moveTuxToNextIceBlock() {
     tuxIsMoving = true
 }
 
-
 function moveTuxToIceBlock() {
     items.tux.x = iceBlocksLayout[tuxIceBlockNumber % iceBlocksLayout.length][0] *
             items.widthBase + (items.widthBase - items.tux.width) / 2
@@ -200,10 +159,7 @@ function moveTuxToIceBlock() {
             items.heightBase + (items.heightBase - items.tux.height) / 2
 }
 
-
-
 function tuxRunningChanged() {
-
     if (tuxIsMoving) {
         moveTuxToNextIceBlock()
     } else {
@@ -214,7 +170,6 @@ function tuxRunningChanged() {
     }
 }
 
-
 function calculateTuxIceBlockNextPos() {
     tuxIceBlockNumberGoal = tuxIceBlockNumber +
             items.chooseDiceBar.value1 + items.chooseDiceBar.value2
@@ -228,9 +183,9 @@ function calculateNextPlaceFishToReach() {
     var newFishIndex
     do {
         newFishIndex = Math.floor(Math.random() *
-                                  (levels[currentLevel].maxNumber * 2 -
-                                   levels[currentLevel].minNumber + 1)) +
-                levels[currentLevel].minNumber
+                                  (items.levels[currentLevel].maxNumber * 2 -
+                                   items.levels[currentLevel].minNumber + 1)) +
+                items.levels[currentLevel].minNumber
     } while((previousFishIndex === newFishIndex) || (newFishIndex >= iceBlocksLayout.length))
     previousFishIndex = newFishIndex
 
@@ -251,7 +206,6 @@ function placeFishToReach() {
             items.heightBase + (items.heightBase - items.fishToReach.height) / 2
 }
 
-
 function nextLevel() {
     if(numberOfLevel <= ++currentLevel) {
         currentLevel = 0
@@ -273,4 +227,3 @@ function lost() {
 function won() {
     items.bonus.good("flower")
 }
-
