@@ -132,8 +132,8 @@ void ActivityInfoTree::filterByTag(const QString &tag, const QString &category,
             (category.isEmpty() && activity->section().indexOf(tag) != -1) ||
             tag == "all" ||
             (tag == "favorite" && activity->favorite())) &&
-            (activity->difficulty() >= ApplicationSettings::getInstance()->filterLevelMin() &&
-             activity->difficulty() <= ApplicationSettings::getInstance()->filterLevelMax())) {
+            (activity->maximalDifficulty() >= ApplicationSettings::getInstance()->filterLevelMin() &&
+             activity->minimalDifficulty() <= ApplicationSettings::getInstance()->filterLevelMax())) {
             m_menuTree.push_back(activity);
         }
     }
@@ -144,27 +144,14 @@ void ActivityInfoTree::filterByTag(const QString &tag, const QString &category,
 
 void ActivityInfoTree::filterByDifficulty(quint32 levelMin, quint32 levelMax)
 {
+    //todo fix here the difficulty filtering
     auto it = std::remove_if(m_menuTree.begin(), m_menuTree.end(),
                              [&](const ActivityInfo* activity) {
-                                 return activity->difficulty() < levelMin || activity->difficulty() > levelMax;
+                                 return activity->minimalDifficulty() < levelMin || activity->maximalDifficulty() > levelMax;
                              });
     m_menuTree.erase(it, m_menuTree.end());
 }
 
-void ActivityInfoTree::filterLockedActivities(bool emitChanged)
-{
-    // If we have the full version or if we show all the activities, we don't need to do anything
-    if(!ApplicationSettings::getInstance()->isDemoMode() || ApplicationSettings::getInstance()->showLockedActivities())
-        return;
-
-    // Remove non free activities if needed. We need to already have a menuTree filled!
-    auto it = std::remove_if(m_menuTree.begin(), m_menuTree.end(),
-                             [](const ActivityInfo* activity) { return !activity->demo(); });
-    m_menuTree.erase(it, m_menuTree.end());
-    if (emitChanged)
-        Q_EMIT menuTreeChanged();
-}
-
 void ActivityInfoTree::filterEnabledActivities(bool emitChanged)
 {
     auto it = std::remove_if(m_menuTree.begin(), m_menuTree.end(),
@@ -191,13 +178,13 @@ void ActivityInfoTree::filterCreatedWithinVersions(int firstVersion,
 
 void ActivityInfoTree::exportAsSQL()
 {
-    QTextStream cout(stdout);
+    QTextStream qtOut(stdout);
 
     ApplicationSettings::getInstance()->setFilterLevelMin(1);
     ApplicationSettings::getInstance()->setFilterLevelMax(6);
     filterByTag("all");
 
-    cout << "CREATE TABLE activities (" <<
+    qtOut << "CREATE TABLE activities (" <<
             "id INT UNIQUE, " <<
             "name TEXT," <<
             "section TEXT," <<
@@ -209,14 +196,13 @@ void ActivityInfoTree::exportAsSQL()
             "prerequisite TEXT," <<
             "goal TEXT," <<
             "manual TEXT," <<
-            "credit TEXT," <<
-            "demo INT);" << endl;
-    cout << "DELETE FROM activities" << endl;
+            "credit TEXT);\n";
+    qtOut << "DELETE FROM activities\n";
 
     int i(0);
     const auto constMenuTree = m_menuTree;
     for(const auto &activity: constMenuTree) {
-        cout << "INSERT INTO activities VALUES(" <<
+        qtOut << "INSERT INTO activities VALUES(" <<
                 i++ << ", " <<
                 "'" << activity->name() << "', " <<
                 "'" << activity->section() << "', " <<
@@ -228,10 +214,10 @@ void ActivityInfoTree::exportAsSQL()
                 "\"" << activity->prerequisite() << "\", " <<
                 "\"" << activity->goal().toHtmlEscaped() << "\", " <<
                 "\"" << activity->manual().toHtmlEscaped() << "\", " <<
-                "\"" << activity->credit() << "\", " <<
-                static_cast<int>(activity->demo()) <<
-                ");" << endl;
+                "\"" << activity->credit() <<
+                ");\n";
     }
+    qtOut.flush();
 }
 
 QObject *ActivityInfoTree::menuTreeProvider(QQmlEngine *engine, QJSEngine *scriptEngine)
@@ -260,7 +246,9 @@ QObject *ActivityInfoTree::menuTreeProvider(QQmlEngine *engine, QJSEngine *scrip
             QQmlComponent componentRoot(engine, QUrl(url));
             QObject *objectRoot = componentRoot.create();
             if(objectRoot != nullptr) {
-                menuTree->menuTreeAppend(qobject_cast<ActivityInfo*>(objectRoot));
+                ActivityInfo* activityInfo = qobject_cast<ActivityInfo*>(objectRoot);
+                activityInfo->fillDatasets(engine);
+                menuTree->menuTreeAppend(activityInfo);
             } else {
                 qDebug() << "ERROR: failed to load " << line << " " << componentRoot.errors();
             }
@@ -269,7 +257,6 @@ QObject *ActivityInfoTree::menuTreeProvider(QQmlEngine *engine, QJSEngine *scrip
     file.close();
 
     menuTree->filterByTag("favorite");
-    menuTree->filterLockedActivities();
     menuTree->filterEnabledActivities();
     return menuTree;
 }
@@ -295,7 +282,11 @@ void ActivityInfoTree::filterBySearch(const QString& text)
     m_menuTree.clear();
     if(!text.trimmed().isEmpty()) {
         // perform search on each word entered in the searchField
+#if QT_VERSION >= QT_VERSION_CHECK(5, 15, 0)
+        const QStringList wordsList = text.split(' ', Qt::SkipEmptyParts);
+#else
         const QStringList wordsList = text.split(' ', QString::SkipEmptyParts);
+#endif
         for(const QString &searchTerm: wordsList) {
             const QString trimmedText = searchTerm.trimmed();
             const auto &constMenuTreeFull = m_menuTreeFull;
@@ -315,12 +306,18 @@ void ActivityInfoTree::filterBySearch(const QString& text)
         m_menuTree = m_menuTreeFull;
 
     filterEnabledActivities(false);
-    filterLockedActivities(false);
     filterByDifficulty(ApplicationSettings::getInstance()->filterLevelMin(), ApplicationSettings::getInstance()->filterLevelMax());
     sortByDifficulty(false);
     Q_EMIT menuTreeChanged();
 }
 
+void ActivityInfoTree::minMaxFiltersChanged(quint32 levelMin, quint32 levelMax, bool emit) {
+    for(ActivityInfo *activity: m_menuTreeFull) {
+        activity->enableDatasetsBetweenDifficulties(levelMin, levelMax);
+    }
+    ApplicationSettings::getInstance()->sync();
+}
+
 QVariantList ActivityInfoTree::allCharacters() {
     QSet<QChar> keyboardChars;
     const auto constMenuTreeFull = m_menuTreeFull;
