@@ -50,13 +50,13 @@ public:
 
 protected Q_SLOTS:
     Q_INVOKABLE void filterByTag(const QString &tag, const QString &category = "", bool emitChanged = true);
-    Q_INVOKABLE void filterLockedActivities(bool emitChanged = true);
     Q_INVOKABLE void filterEnabledActivities(bool emitChanged = true);
     // create a tree from the whole list of activities with the activities created between the two versions
     Q_INVOKABLE void filterCreatedWithinVersions(int firstVersion, int lastVersion,
                                                  bool emitChanged = true);
     Q_INVOKABLE void filterBySearch(const QString& text);
     Q_INVOKABLE void filterByDifficulty(quint32 levelMin, quint32 levelMax);
+    Q_INVOKABLE void minMaxFiltersChanged(quint32 levelMin, quint32 levelMax, bool emitChanged = true);
 
 signals:
     void menuTreeChanged();
@@ -78,7 +78,7 @@ private:
     {
         bool operator()(const ActivityInfo *a, const ActivityInfo *b) const
         {
-            return a->difficulty() < b->difficulty();
+            return a->minimalDifficulty() < b->minimalDifficulty();
         }
     };
 
