@@ -77,7 +77,7 @@ ApplicationInfo::ApplicationInfo(QObject *parent): QObject(parent)
     QRect rect = qApp->primaryScreen()->geometry();
     m_ratio = qMin(qMax(rect.width(), rect.height())/800. , qMin(rect.width(), rect.height())/520.);
     // calculate a factor for font-scaling, cf.
-    // http://doc.qt.io/qt-5/scalability.html#calculating-scaling-ratio
+    // https://doc.qt.io/qt-5/scalability.html#calculating-scaling-ratio
     qreal refDpi = 216.;
     qreal refHeight = 1776.;
     qreal refWidth = 1080.;
@@ -94,7 +94,7 @@ ApplicationInfo::ApplicationInfo(QObject *parent): QObject(parent)
         connect(qApp->primaryScreen(), &QScreen::physicalSizeChanged, this, &ApplicationInfo::notifyPortraitMode);
 
 // @FIXME this does not work on iOS: https://bugreports.qt.io/browse/QTBUG-50624
-#if not defined(Q_OS_IOS)
+#if !defined(Q_OS_IOS)
     // Get all symbol fonts to remove them
     QFontDatabase database;
     m_excludedFonts = database.families(QFontDatabase::Symbol);
