@@ -97,7 +97,7 @@ class ApplicationInfo : public QObject
      *
      * For these cases we calculate a fontRatio in ApplicationInfo that takes
      * dpi information into account, as proposed on
-     * http://doc.qt.io/qt-5/scalability.html#calculating-scaling-ratio
+     * https://doc.qt.io/qt-5/scalability.html#calculating-scaling-ratio
      *
      * GCText applies this factor automatically on its new fontSize property.
      */
@@ -191,6 +191,9 @@ public:
         QString _locale = locale;
         if(_locale == GC_DEFAULT_LOCALE) {
             _locale = QLocale::system().name();
+        } 
+        if(_locale == "C") {
+            _locale = "en_US";
         }
         // Can't use left(2) because of Asturian where there are 3 chars
         return _locale.left(_locale.indexOf('_'));
@@ -301,10 +304,10 @@ public:
     /**
      * Change the desired orientation of the application.
      *
-     * Android specific function, cf. http://developer.android.com/reference/android/app/Activity.html#setRequestedOrientation(int)
+     * Android specific function, cf. https://developer.android.com/reference/android/app/Activity.html#setRequestedOrientation(int)
      *
      * @param orientation Desired orientation of the application. For possible
-     *                    values cf. http://developer.android.com/reference/android/content/pm/ActivityInfo.html#screenOrientation .
+     *                    values cf. https://developer.android.com/reference/android/content/pm/ActivityInfo.html#screenOrientation .
      *                    Some useful values:
      *                    - -1: SCREEN_ORIENTATION_UNSPECIFIED
      *                    -  0: SCREEN_ORIENTATION_LANDSCAPE: forces landscape
@@ -340,6 +343,16 @@ public:
      */
     Q_INVOKABLE void setKeepScreenOn(bool value);
 
+    /**
+     * Ask for permissions for reading/writing in storage for android.
+     * Do nothing for other platforms.
+     *
+     * https://developer.android.com/training/permissions/requesting
+     * https://doc.qt.io/qt-5/qtandroid.html#requestPermissions
+     * Needed for android above 6.0
+     */
+    bool checkPermissions() const;
+
     /// @endcond
 
 public slots:
