@@ -42,11 +42,11 @@ static const char *GENERAL_GROUP_KEY = "General";
 static const char *ADMIN_GROUP_KEY = "Admin";
 static const char *INTERNAL_GROUP_KEY = "Internal";
 static const char *FAVORITE_GROUP_KEY = "Favorite";
+static const char *LEVELS_GROUP_KEY = "Levels";
 
 static const char *FULLSCREEN_KEY = "fullscreen";
 static const char *PREVIOUS_HEIGHT_KEY = "previousHeight";
 static const char *PREVIOUS_WIDTH_KEY = "previousWidth";
-static const char *SHOW_LOCKED_ACTIVITIES_KEY = "showLockedActivities";
 static const char *ENABLE_AUDIO_VOICES_KEY = "enableAudioVoices";
 static const char *ENABLE_AUDIO_EFFECTS_KEY = "enableAudioEffects";
 static const char *ENABLE_BACKGROUND_MUSIC_KEY = "enableBackgroundMusic";
@@ -76,11 +76,10 @@ static const char *FONT_LETTER_SPACING = "fontLetterSpacing";
 
 static const char *DEFAULT_CURSOR = "defaultCursor";
 static const char *NO_CURSOR = "noCursor";
-static const char *DEMO_KEY = "demo";
-static const char *CODE_KEY = "key";
 static const char *KIOSK_KEY = "kiosk";
 static const char *SECTION_VISIBLE = "sectionVisible";
 static const char *WORDSET = "wordset";
+static const char *USE_WORDSET = "useWordset";
 
 static const char *PROGRESS_KEY = "progress";
 
@@ -117,34 +116,15 @@ ApplicationSettings::ApplicationSettings(const QString &configPath, QObject *par
     m_backgroundMusicVolume = m_config.value(BACKGROUND_MUSIC_VOLUME_KEY, 0.2).toReal();
     m_audioEffectsVolume = m_config.value(AUDIO_EFFECTS_VOLUME_KEY, 0.7).toReal();
 
-    // Init the activation mode
-    if(QLatin1String(ACTIVATION_MODE) == "no")
-        m_activationMode = 0;
-    else if(QLatin1String(ACTIVATION_MODE) == "inapp")
-        m_activationMode = 1;
-    else if(QLatin1String(ACTIVATION_MODE) == "internal")
-        m_activationMode = 2;
-    else
-        qFatal("Unknown activation mode");
-
-    // Set the demo mode
-    if(QLatin1String(ACTIVATION_MODE) != "no")
-        m_isDemoMode = m_config.value(DEMO_KEY, true).toBool();
-    else
-        m_isDemoMode = false;
-    m_codeKey = m_config.value(CODE_KEY, "").toString();
-
 #if defined(WITH_KIOSK_MODE)
     m_isKioskMode = m_config.value(KIOSK_KEY, true).toBool();
 #else
     m_isKioskMode = m_config.value(KIOSK_KEY, false).toBool();
 #endif
 
-    // Option only useful if we are in demo mode (else all the activities are available and unlocked)
-    // By default, all the activities are displayed (even locked ones)
-    m_showLockedActivities = m_config.value(SHOW_LOCKED_ACTIVITIES_KEY, m_isDemoMode).toBool();
     m_sectionVisible = m_config.value(SECTION_VISIBLE, true).toBool();
     m_wordset = m_config.value(WORDSET, "").toString();
+    m_useWordset = m_config.value(USE_WORDSET, true).toBool();
     m_isAutomaticDownloadsEnabled = m_config.value(ENABLE_AUTOMATIC_DOWNLOADS,
             !ApplicationInfo::getInstance()->isMobile() && ApplicationInfo::isDownloadAllowed()).toBool();
     m_filterLevelMin = m_config.value(FILTER_LEVEL_MIN, 1).toUInt();
@@ -176,7 +156,6 @@ ApplicationSettings::ApplicationSettings(const QString &configPath, QObject *par
     // no group
     m_isBarHidden = false;
 
-    connect(this, &ApplicationSettings::showLockedActivitiesChanged, this, &ApplicationSettings::notifyShowLockedActivitiesChanged);
     connect(this, &ApplicationSettings::audioVoicesEnabledChanged, this, &ApplicationSettings::notifyAudioVoicesEnabledChanged);
     connect(this, &ApplicationSettings::audioEffectsEnabledChanged, this, &ApplicationSettings::notifyAudioEffectsEnabledChanged);
     connect(this, &ApplicationSettings::backgroundMusicEnabledChanged, this, &ApplicationSettings::notifyBackgroundMusicEnabledChanged);
@@ -192,8 +171,7 @@ ApplicationSettings::ApplicationSettings(const QString &configPath, QObject *par
     connect(this, &ApplicationSettings::filterLevelMaxChanged, this, &ApplicationSettings::notifyFilterLevelMaxChanged);
     connect(this, &ApplicationSettings::sectionVisibleChanged, this, &ApplicationSettings::notifySectionVisibleChanged);
     connect(this, &ApplicationSettings::wordsetChanged, this, &ApplicationSettings::notifyWordsetChanged);
-    connect(this, &ApplicationSettings::demoModeChanged, this, &ApplicationSettings::notifyDemoModeChanged);
-    connect(this, &ApplicationSettings::codeKeyChanged, this, &ApplicationSettings::notifyCodeKeyChanged);
+    connect(this, &ApplicationSettings::useWordsetChanged, this, &ApplicationSettings::notifyUseWordsetChanged);
     connect(this, &ApplicationSettings::kioskModeChanged, this, &ApplicationSettings::notifyKioskModeChanged);
     connect(this, &ApplicationSettings::downloadServerUrlChanged, this, &ApplicationSettings::notifyDownloadServerUrlChanged);
     connect(this, &ApplicationSettings::cachePathChanged, this, &ApplicationSettings::notifyCachePathChanged);
@@ -211,7 +189,6 @@ ApplicationSettings::~ApplicationSettings()
     // make sure settings file is up2date:
     // general group
     m_config.beginGroup(GENERAL_GROUP_KEY);
-    m_config.setValue(SHOW_LOCKED_ACTIVITIES_KEY, m_showLockedActivities);
     m_config.setValue(ENABLE_AUDIO_VOICES_KEY, m_isAudioVoicesEnabled);
     m_config.setValue(ENABLE_BACKGROUND_MUSIC_KEY, m_isBackgroundMusicEnabled);
     m_config.setValue(FILTERED_BACKGROUND_MUSIC_KEY, m_filteredBackgroundMusic);
@@ -227,11 +204,10 @@ ApplicationSettings::~ApplicationSettings()
     m_config.setValue(ENABLE_AUTOMATIC_DOWNLOADS, m_isAutomaticDownloadsEnabled);
     m_config.setValue(FILTER_LEVEL_MIN, m_filterLevelMin);
     m_config.setValue(FILTER_LEVEL_MAX, m_filterLevelMax);
-    m_config.setValue(DEMO_KEY, m_isDemoMode);
-    m_config.setValue(CODE_KEY, m_codeKey);
     m_config.setValue(KIOSK_KEY, m_isKioskMode);
     m_config.setValue(SECTION_VISIBLE, m_sectionVisible);
     m_config.setValue(WORDSET, m_wordset);
+    m_config.setValue(USE_WORDSET, m_useWordset);
     m_config.setValue(DEFAULT_CURSOR, m_defaultCursor);
     m_config.setValue(NO_CURSOR, m_noCursor);
     m_config.setValue(BASE_FONT_SIZE_KEY, m_baseFontSize);
@@ -258,12 +234,6 @@ ApplicationSettings::~ApplicationSettings()
     m_instance = nullptr;
 }
 
-void ApplicationSettings::notifyShowLockedActivitiesChanged()
-{
-    updateValueInConfig(GENERAL_GROUP_KEY, SHOW_LOCKED_ACTIVITIES_KEY, m_showLockedActivities);
-    qDebug() << "notifyShowLockedActivitiesChanged: " << m_showLockedActivities;
-}
-
 void ApplicationSettings::notifyAudioVoicesEnabledChanged()
 {
     updateValueInConfig(GENERAL_GROUP_KEY, ENABLE_AUDIO_VOICES_KEY, m_isAudioVoicesEnabled);
@@ -381,20 +351,6 @@ void ApplicationSettings::notifyFilterLevelMaxChanged()
     qDebug() << "filterLevelMax set to: " << m_filterLevelMax;
 }
 
-void ApplicationSettings::notifyDemoModeChanged()
-{
-    updateValueInConfig(GENERAL_GROUP_KEY, DEMO_KEY, m_isDemoMode);
-    qDebug() << "notifyDemoMode: " << m_isDemoMode;
-}
-
-void ApplicationSettings::notifyCodeKeyChanged()
-{
-    checkPayment();
-    if(!m_isDemoMode)
-        updateValueInConfig(GENERAL_GROUP_KEY, CODE_KEY, m_codeKey);
-    qDebug() << "notifyCodeKey: " << m_codeKey;
-}
-
 void ApplicationSettings::notifyKioskModeChanged()
 {
     updateValueInConfig(GENERAL_GROUP_KEY, KIOSK_KEY, m_isKioskMode);
@@ -421,6 +377,12 @@ void ApplicationSettings::notifyWordsetChanged()
     qDebug() << "notifyWordset: " << m_wordset;
 }
 
+void ApplicationSettings::notifyUseWordsetChanged()
+{
+    updateValueInConfig(GENERAL_GROUP_KEY, USE_WORDSET, m_useWordset);
+    qDebug() << "notifyUseWordset: " << m_useWordset;
+}
+
 void ApplicationSettings::notifyDownloadServerUrlChanged()
 {
     updateValueInConfig(ADMIN_GROUP_KEY, DOWNLOAD_SERVER_URL_KEY, m_downloadServerUrl);
@@ -473,8 +435,9 @@ void ApplicationSettings::saveActivityConfiguration(const QString &activity, con
     QMapIterator<QString, QVariant> i(data);
     while (i.hasNext()) {
         i.next();
-        updateValueInConfig(activity, i.key(), i.value());
+        updateValueInConfig(activity, i.key(), i.value(), false);
     }
+    m_config.sync();
 }
 
 QVariantMap ApplicationSettings::loadActivityConfiguration(const QString &activity)
@@ -492,23 +455,42 @@ QVariantMap ApplicationSettings::loadActivityConfiguration(const QString &activi
 
 void ApplicationSettings::setFavorite(const QString &activity, bool favorite)
 {
-	updateValueInConfig(FAVORITE_GROUP_KEY, activity, favorite);
+    updateValueInConfig(FAVORITE_GROUP_KEY, activity, favorite);
 }
 
 bool ApplicationSettings::isFavorite(const QString &activity)
 {
-	m_config.beginGroup(FAVORITE_GROUP_KEY);
-	bool favorite = m_config.value(activity, false).toBool();
-	m_config.endGroup();
-	return favorite;
+    m_config.beginGroup(FAVORITE_GROUP_KEY);
+    bool favorite = m_config.value(activity, false).toBool();
+    m_config.endGroup();
+    return favorite;
+}
+
+void ApplicationSettings::setCurrentLevels(const QString &activity, const QStringList &level, bool sync)
+{
+    updateValueInConfig(LEVELS_GROUP_KEY, activity, level, sync);
+}
+
+QStringList ApplicationSettings::currentLevels(const QString &activity)
+{
+    m_config.beginGroup(LEVELS_GROUP_KEY);
+    QStringList level = m_config.value(activity, QStringList()).toStringList();
+    m_config.endGroup();
+    return level;
 }
 
 template<class T> void ApplicationSettings::updateValueInConfig(const QString& group,
-                                              const QString& key, const T& value)
+                                              const QString& key, const T& value, bool sync)
 {
     m_config.beginGroup(group);
     m_config.setValue(key, value);
     m_config.endGroup();
+    if(sync) {
+        m_config.sync();
+    }
+}
+
+void ApplicationSettings::sync() {
     m_config.sync();
 }
 
