@@ -87,7 +87,7 @@ void DownloadManager::abortDownloads()
         QMutableListIterator<DownloadJob*> iter(activeJobs);
         while (iter.hasNext()) {
             DownloadJob *job = iter.next();
-            if (job->reply != nullptr) {
+            if (!job->downloadFinished && job->reply != nullptr) {
                 disconnect(job->reply, SIGNAL(finished()), this, SLOT(downloadFinished()));
                 disconnect(job->reply, SIGNAL(error(QNetworkReply::NetworkError)),
                         this, SLOT(handleError(QNetworkReply::NetworkError)));
@@ -99,6 +99,7 @@ void DownloadManager::abortDownloads()
                 }
                 job->reply->deleteLater();
             }
+            delete job;
             iter.remove();
         }
         locker.unlock();
@@ -129,7 +130,11 @@ inline QString DownloadManager::getAbsoluteResourcePath(const QString& path) con
 // @FIXME should support a variable subpath length like data2/full.rcc"
 inline QString DownloadManager::getRelativeResourcePath(const QString& path) const
 {
+#if QT_VERSION >= QT_VERSION_CHECK(5, 15, 0)
+    QStringList parts = path.split('/', Qt::SkipEmptyParts);
+#else
     QStringList parts = path.split('/', QString::SkipEmptyParts);
+#endif
     if (parts.size() < 3)
         return QString();
     return QString(parts[parts.size()-3] + '/' + parts[parts.size()-2]
@@ -240,7 +245,7 @@ bool DownloadManager::download(DownloadJob* job)
             this, SLOT(handleError(QNetworkReply::NetworkError)));
     if (job->url.fileName() != contentsFilename) {
         connect(reply, &QNetworkReply::downloadProgress,
-                this, &DownloadManager::downloadProgress);
+                this, &DownloadManager::downloadInProgress);
         emit downloadStarted(job->url.toString().remove(0, serverUrl.toString().length()));
     }
 
@@ -301,10 +306,8 @@ inline QStringList DownloadManager::getSystemResourcePaths() const
             '/' + GCOMPRIS_APPLICATION_NAME
     });
 
-#if QT_VERSION >= 0x050400
     // Append standard application directories (like /usr/share/KDE/gcompris-qt)
     results += QStandardPaths::standardLocations(QStandardPaths::AppDataLocation);
-#endif
 
     return results;
 }
@@ -352,7 +355,11 @@ bool DownloadManager::parseContents(DownloadJob *job)
     QTextStream in(&job->file);
     while (!in.atEnd()) {
         QString line = in.readLine();
+#if QT_VERSION >= QT_VERSION_CHECK(5, 15, 0)
+        QStringList parts = line.split(' ', Qt::SkipEmptyParts);
+#else
         QStringList parts = line.split(' ', QString::SkipEmptyParts);
+#endif
         if (parts.size() != 2) {
             qWarning() << "Invalid format of Contents file!";
             return false;
@@ -459,11 +466,33 @@ bool DownloadManager::areVoicesRegistered() const
     return isDataRegistered(resource);
 }
 
+void DownloadManager::downloadInProgress(qint64 bytesReceived, qint64 bytesTotal) {
+    QNetworkReply *reply = dynamic_cast<QNetworkReply*>(sender());
+    DownloadJob *job = nullptr;
+    // don't call getJobByReply to not cause deadlock with mutex
+    for (auto activeJob : activeJobs) {
+        if (activeJob->reply == reply) {
+            job = activeJob;
+            break;
+        }
+    }
+    job->bytesReceived = bytesReceived;
+    job->bytesTotal = bytesTotal;
+    qint64 allJobsBytesReceived = 0;
+    qint64 allJobsBytesTotal = 0;
+    for (auto activeJob : activeJobs) {
+        allJobsBytesReceived += activeJob->bytesReceived;
+        allJobsBytesTotal += activeJob->bytesTotal;
+    }
+    emit downloadProgress(allJobsBytesReceived, allJobsBytesTotal);
+}
+
 void DownloadManager::downloadFinished()
 {
     QNetworkReply* reply = dynamic_cast<QNetworkReply*>(sender());
     DownloadFinishedCode code = Success;
     DownloadJob *job = getJobByReply(reply);
+    bool allFinished = false;
     if (job->file.isOpen()) {
         job->file.flush();  // note: important, or checksums might be wrong!
         job->file.close();
@@ -562,15 +591,27 @@ void DownloadManager::downloadFinished()
         }
 
     // none left, DownloadJob finished
+    job->downloadFinished = true;
+    job->downloadResult = code;
     if (job->file.isOpen())
         job->file.close();
-    { // note: must remove before signalling downloadFinished(), otherwise race condition for the Qt.quit() case
-        QMutexLocker locker(&jobsMutex);
-        activeJobs.removeOne(job);
-    }
     emit downloadFinished(code);
     reply->deleteLater();
-    delete job;
+
+    allFinished = std::all_of(activeJobs.constBegin(), activeJobs.constEnd(),
+                              [](const DownloadJob* job) { return job->downloadFinished;});
+    if(allFinished) {
+        QMutexLocker locker(&jobsMutex);
+        DownloadFinishedCode allCode = Success;
+        std::for_each(activeJobs.constBegin(), activeJobs.constEnd(),
+                      [&allCode] (const DownloadJob *job) {
+                          if(job->downloadResult == Error)
+                              allCode = Error;
+                          delete job;
+                      });
+        activeJobs.clear();
+        emit allDownloadsFinished(allCode);
+    }
     return;
 
   outError:
