@@ -244,3 +244,59 @@ function isLeftToRightLocale(locale) {
     var localeShort = GCompris.ApplicationInfo.getVoicesLocale(locale)
     return (localeShort != "ar" && localeShort != "he");
 }
+
+function resolveLocale(localeToSet) {
+    // Resolve the locale used to a real one
+    // if Gcompris' locale selected, we want the real locale
+    // and if GCompris' locale is system, then resolve again
+    var newLocale = localeToSet
+    if(newLocale === "system") {
+        newLocale = GCompris.ApplicationSettings.locale
+        // Remove .UTF-8
+        if(newLocale.indexOf('.') != -1) {
+            newLocale = newLocale.substring(0, newLocale.indexOf('.'))
+        }
+        return newLocale
+    }
+    else {
+        return localeToSet
+    }
+}
+
+/**
+ * Function that returns the best cell size for a grid of a given
+ * width and height and a number of items.
+ *
+ * Formula inspired from https://math.stackexchange.com/questions/466198/algorithm-to-get-the-maximum-size-of-n-squares-that-fit-into-a-rectangle-with-a
+ *
+ * @param x_: grid width
+ * @param y_: grid height
+ * @param n_: number of items to place in the grid
+ * @param extra_: optional extra number to add to sides calculation
+ */
+function fitItems(x_, y_, n_, extra_) {
+    var sx
+    var sy
+
+    if(x_ <= 0 || y_ <= 0 || n_ <= 0)
+        return 10; // return default value that will be erased later, to avoid crash on Android
+
+    if(extra_ === undefined)
+        extra_ = 0;
+
+    var px = Math.ceil(Math.sqrt(n_ * x_ / y_)) + extra_;
+    if (Math.floor(px * y_ / x_) * px < n_) {
+        sx = y_ / Math.ceil(px * y_ / x_);
+    } else {
+        sx = x_ / px;
+    }
+
+    var py = Math.ceil(Math.sqrt(n_ * y_ / x_)) + extra_;
+    if (Math.floor(py * x_ / y_) * py < n_) {
+        sy = x_ / Math.ceil(x_ *  py / y_);
+    } else {
+        sy = y_ / py;
+    }
+
+    return Math.max(sx, sy);
+}
