@@ -119,7 +119,7 @@ int main(int argc, char *argv[])
     //add a variable to disable default fullscreen on Mac, see below..
 #if defined(Q_OS_MAC)
     // Sandboxing on MacOSX as documented in:
-    // http://doc.qt.io/qt-5/osx-deployment.html
+    // https://doc.qt.io/qt-5/osx-deployment.html
     QDir dir(QGuiApplication::applicationDirPath());
     dir.cdUp();
     dir.cd("Plugins");
@@ -184,9 +184,8 @@ int main(int argc, char *argv[])
     // Tell media players to stop playing, it's GCompris time
     ApplicationInfo::getInstance()->requestAudioFocus();
 
-    // Must be done after ApplicationSettings is constructed because we get an
-    // async callback from the payment system
-    ApplicationSettings::getInstance()->checkPayment();
+    // For android, request the permissions if not already allowed
+    ApplicationInfo::getInstance()->checkPermissions();
 
     // Disable default fullscreen launch on Mac as it's a bit broken, window is behind desktop bars
 #if defined(Q_OS_MAC)
